@@ -27,6 +27,7 @@ To get your credentials:
 #################################################################
 
 def main(args=sys.argv[1:]):
+    """Run the commandline script"""
     usage = "%prog --help"
     parser = OptionParser(usage, add_help_option=False)
     parser.add_option('-c', '--config', help="Configuration file to use",
@@ -90,8 +91,8 @@ def main(args=sys.argv[1:]):
         params, files = extract_files(params)
         result = client.post(options.endpoint, process_response=False,
                              files=files, **params)
-        for f in files:
-            files[f].close()
+        for file_ in files:
+            files[file_].close()
 
     if options.verbose:
         print("==========\nMethod: %s\nHost: %s\nEndpoint: %s" %
@@ -121,13 +122,12 @@ def extract_files(params):
     files = {}
     updated_params = {}
     for name in params:
-        if (name == "photo" and params[name].startswith("@") and
-                os.path.isfile(os.path.expanduser(params[name][1:]))):
-            files[name] = open(params[name][1:], 'rb')
+        if name == "photo" and params[name].startswith("@"):
+            files[name] = open(os.path.expanduser(params[name][1:]), 'rb')
         else:
             updated_params[name] = params[name]
 
     return updated_params, files
 
-if __name__ == "__main__":
+if __name__ == "__main__": # pragma: no cover
     main()
